# Changelog

## [1.0.1](https://github.com/spdcalc/spdcalc-py/compare/0.1.0-alpha.4...v1.0.1) (2024-10-22)


### ⚠ BREAKING CHANGES

* remove elliptical waist support

### Features

* ability to use custom expression for crystal_kind ([40722af](https://github.com/spdcalc/spdcalc-py/commit/40722afdbb1f8c305c353ac4a16ff1632640fd62))
* added x_values and y_values for si spaces ([c1c6cc7](https://github.com/spdcalc/spdcalc-py/commit/c1c6cc7eef46d715ceba7e533c33a4ff35f95724))


### Bug Fixes

* general documentation fixes ([a811a0d](https://github.com/spdcalc/spdcalc-py/commit/a811a0d2bbb5e9bf0e3482391d92a26c671cca91))
* remove elliptical waist support ([74d36e4](https://github.com/spdcalc/spdcalc-py/commit/74d36e46ecb0175f785751d6d6dbadc06f1933b9))


### ⚠ BREAKING CHANGES

* remove elliptical waist support

### Bug Fixes

* remove elliptical waist support ([74d36e4](https://github.com/spdcalc/spdcalc-py/commit/74d36e46ecb0175f785751d6d6dbadc06f1933b9))
